@@ -21,7 +21,7 @@
 #include <syncengine.h>
 #include "updatee2eefolderusersmetadatajob.h"
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 #include <CoreServices/CoreServices.h>
 #endif
 
@@ -348,15 +348,11 @@ int FolderMan::setupFoldersMigration()
     ConfigFile cfg;
     QDir storageDir(cfg.configPath());
     _folderConfigPath = cfg.configPath();
-    auto configPath = _folderConfigPath;
 
-#if !DISABLE_ACCOUNT_MIGRATION
-    if (const auto legacyConfigPath = ConfigFile::discoveredLegacyConfigPath();!legacyConfigPath.isEmpty()) {
-        configPath =  legacyConfigPath;
-        qCInfo(lcFolderMan) << "Starting folder migration from legacy path:" << legacyConfigPath;
-    }
-#endif
-    qCInfo(lcFolderMan) << "Setup folders from" << configPath;
+    const auto legacyConfigPath = ConfigFile::discoveredLegacyConfigPath();
+    const auto configPath = legacyConfigPath.isEmpty() ? _folderConfigPath : legacyConfigPath;
+
+    qCInfo(lcFolderMan) << "Setup folders from " << configPath << "(migration)";
 
     QDir dir(configPath);
     // We need to include hidden files just in case the alias starts with '.'
@@ -389,7 +385,8 @@ void FolderMan::backwardMigrationSettingsKeys(QStringList *deleteKeys, QStringLi
         const auto foldersVersion = settings->value(QLatin1String(settingsVersionC), 1).toInt();
         qCInfo(lcFolderMan) << "FolderDefinition::maxSettingsVersion:" << FolderDefinition::maxSettingsVersion();
         if (foldersVersion <= maxFoldersVersion) {
-            for (const auto &folderAlias : settings->childGroups()) {
+            const auto &childGroups = settings->childGroups();
+            for (const auto &folderAlias : childGroups) {
                 settings->beginGroup(folderAlias);
                 const auto folderVersion = settings->value(QLatin1String(settingsVersionC), 1).toInt();
                 if (folderVersion > FolderDefinition::maxSettingsVersion()) {
@@ -595,7 +592,7 @@ void FolderMan::setupLegacyFolder(const QString &fileNamePath, AccountState *acc
                 legacyBlacklist << settings.value(QLatin1String("blackList")).toStringList();
                 if (!legacyBlacklist.isEmpty()) {
                     qCInfo(lcFolderMan) << "Legacy selective sync list found:" << legacyBlacklist;
-                    for (const auto &legacyFolder : legacyBlacklist) {
+                    for (const auto &legacyFolder : std::as_const(legacyBlacklist)) {
                         folder->migrateBlackListPath(legacyFolder);
                     }
                     settings.remove(QLatin1String("blackList"));
