@@ -18,13 +18,14 @@
 #if defined(BUILD_UPDATER)
 #include "updater/updater.h"
 #include "updater/ocupdater.h"
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 // FIXME We should unify those, but Sparkle does everything behind the scene transparently
 #include "updater/sparkleupdater.h"
 #endif
 #endif
 
 #ifdef BUILD_FILE_PROVIDER_MODULE
+#include "macOS/fileproviderutils.h"
 #include "macOS/fileprovider.h"
 #include "macOS/fileprovidersettingscontroller.h"
 #endif
@@ -39,6 +40,7 @@
 #include <QMessageBox>
 #include <QNetworkProxy>
 #include <QDir>
+#include <QDirIterator>
 #include <QScopedValueRollback>
 #include <QMessageBox>
 
@@ -139,33 +141,37 @@ bool createDebugArchive(const QString &filename)
     }
 
 #ifdef BUILD_FILE_PROVIDER_MODULE
-    const auto fileProvider = OCC::Mac::FileProvider::instance();
-    if (fileProvider && fileProvider->fileProviderAvailable()) {
-        const auto tempDir = QTemporaryDir();
-        const auto xpc = fileProvider->xpc();
-        const auto vfsAccounts = OCC::Mac::FileProviderSettingsController::instance()->vfsEnabledAccounts();
-        for (const auto &accountUserIdAtHost : vfsAccounts) {
-            const auto accountState = OCC::AccountManager::instance()->accountFromUserId(accountUserIdAtHost);
-            if (!accountState) {
-                qWarning() << "Could not find account for" << accountUserIdAtHost;
-                continue;
-            }
-            const auto account = accountState->account();
-            const auto vfsLogFilename = QStringLiteral("macOS_vfs_%1.log").arg(account->davUser());
-            const auto vfsLogPath = tempDir.filePath(vfsLogFilename);
-            xpc->createDebugArchiveForExtension(accountUserIdAtHost, vfsLogPath);
-            zip.addLocalFile(vfsLogPath, vfsLogFilename);
+    qDebug() << "Trying to add file provider domain log files...";
+    const auto fileProviderExtensionLogDirectory = OCC::Mac::FileProviderUtils::fileProviderExtensionLogDirectory();
+
+    if (fileProviderExtensionLogDirectory.exists()) {
+        // Recursively add all files from the container log directory
+        QDirIterator it(fileProviderExtensionLogDirectory.path(), QDir::Files | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
+
+        while (it.hasNext()) {
+            const auto logFilePath = it.next();
+            const auto logFileInfo = QFileInfo(logFilePath);
+
+            // Calculate relative path from the base container log directory
+            const auto relativePath = fileProviderExtensionLogDirectory.relativeFilePath(logFilePath);
+            const auto zipPath = QStringLiteral("File Provider Domains/%1").arg(relativePath);
+
+            zip.addLocalFile(logFilePath, zipPath);
         }
+
+        qDebug() << "Added file provider domain log files from" << fileProviderExtensionLogDirectory.path();
+    } else {
+        qWarning() << "file provider domain container log directory not found at" << fileProviderExtensionLogDirectory.path();
     }
 #endif
 
     const auto clientParameters = QCoreApplication::arguments().join(' ').toUtf8();
-    zip.prepareWriting("__nextcloud_client_parameters.txt", {}, {}, clientParameters.size());
+    zip.prepareWriting("_client_parameters.txt", {}, {}, clientParameters.size());
     zip.writeData(clientParameters, clientParameters.size());
     zip.finishWriting(clientParameters.size());
 
     const auto buildInfo = QString(OCC::Theme::instance()->aboutInfo() + "\n\n" + OCC::Theme::instance()->aboutDetails()).toUtf8();
-    zip.prepareWriting("__nextcloud_client_buildinfo.txt", {}, {}, buildInfo.size());
+    zip.prepareWriting("_client_buildinfo.txt", {}, {}, buildInfo.size());
     zip.writeData(buildInfo, buildInfo.size());
     zip.finishWriting(buildInfo.size());
     return true;
@@ -182,7 +188,7 @@ GeneralSettings::GeneralSettings(QWidget *parent)
     _ui->setupUi(this);
 
     updatePollIntervalVisibility();
-    
+
     connect(_ui->serverNotificationsCheckBox, &QAbstractButton::toggled,
         this, &GeneralSettings::slotToggleOptionalServerNotifications);
     _ui->serverNotificationsCheckBox->setToolTip(tr("Server notifications that require attention."));
@@ -195,10 +201,13 @@ GeneralSettings::GeneralSettings(QWidget *parent)
         this, &GeneralSettings::slotToggleCallNotifications);
     _ui->callNotificationsCheckBox->setToolTip(tr("Show call notification dialogs."));
 
+    connect(_ui->quotaWarningNotificationsCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotToggleQuotaWarningNotifications);
+    _ui->quotaWarningNotificationsCheckBox->setToolTip(tr("Show notification when quota usage exceeds 80%."));
+
     connect(_ui->showInExplorerNavigationPaneCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotShowInExplorerNavigationPane);
 
     // Rename 'Explorer' appropriately on non-Windows
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     QString txt = _ui->showInExplorerNavigationPaneCheckBox->text();
     txt.replace(QString::fromLatin1("Explorer"), QString::fromLatin1("Finder"));
     _ui->showInExplorerNavigationPaneCheckBox->setText(txt);
@@ -208,7 +217,7 @@ GeneralSettings::GeneralSettings(QWidget *parent)
         _ui->autostartCheckBox->setChecked(hasSystemAutoStart);
         _ui->autostartCheckBox->setDisabled(hasSystemAutoStart);
         _ui->autostartCheckBox->setToolTip(tr("You cannot disable autostart because system-wide autostart is enabled."));
-    } else {       
+    } else {
         connect(_ui->autostartCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotToggleLaunchOnStartup);
         _ui->autostartCheckBox->setChecked(ConfigFile().launchOnSystemStartup());
     }
@@ -236,7 +245,7 @@ GeneralSettings::GeneralSettings(QWidget *parent)
     connect(_ui->newExternalStorage, &QAbstractButton::toggled, this, &GeneralSettings::saveMiscSettings);
     connect(_ui->moveFilesToTrashCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::saveMiscSettings);
     connect(_ui->remotePollIntervalSpinBox, &QSpinBox::valueChanged, this, &GeneralSettings::slotRemotePollIntervalChanged);
-    
+
     // Hide on non-Windows, or WindowsVersion < 10.
     // The condition should match the default value of ConfigFile::showInExplorerNavigationPane.
 #ifdef Q_OS_WIN
@@ -298,6 +307,8 @@ void GeneralSettings::loadMiscSettings()
     _ui->chatNotificationsCheckBox->setChecked(cfgFile.showChatNotifications());
     _ui->callNotificationsCheckBox->setEnabled(cfgFile.optionalServerNotifications());
     _ui->callNotificationsCheckBox->setChecked(cfgFile.showCallNotifications());
+    _ui->quotaWarningNotificationsCheckBox->setEnabled(cfgFile.optionalServerNotifications());
+    _ui->quotaWarningNotificationsCheckBox->setChecked(cfgFile.showQuotaWarningNotifications());
     _ui->showInExplorerNavigationPaneCheckBox->setChecked(cfgFile.showInExplorerNavigationPane());
     _ui->newExternalStorage->setChecked(cfgFile.confirmExternalStorage());
     _ui->monoIconsCheckBox->setChecked(cfgFile.monoIcons());
@@ -313,9 +324,9 @@ void GeneralSettings::loadMiscSettings()
     _ui->newExternalStorage->setChecked(cfgFile.confirmExternalStorage());
     _ui->monoIconsCheckBox->setChecked(cfgFile.monoIcons());
 
-    const auto interval = cfgFile.remotePollInterval(); 
+    const auto interval = cfgFile.remotePollInterval();
     _ui->remotePollIntervalSpinBox->setValue(static_cast<int>(interval.count() / 1000));
-    updatePollIntervalVisibility(); 
+    updatePollIntervalVisibility();
 }
 
 #if defined(BUILD_UPDATER)
@@ -385,7 +396,7 @@ void GeneralSettings::slotUpdateInfo()
                                       ocupdater->downloadState() != OCUpdater::Downloading &&
                                       ocupdater->downloadState() != OCUpdater::DownloadComplete);
     }
-#if defined(Q_OS_MAC) && defined(HAVE_SPARKLE)
+#if defined(Q_OS_MACOS) && defined(HAVE_SPARKLE)
     else if (const auto sparkleUpdater = qobject_cast<SparkleUpdater *>(updater)) {
         connect(sparkleUpdater, &SparkleUpdater::statusChanged, this, &GeneralSettings::slotUpdateInfo, Qt::UniqueConnection);
         _ui->updateStateLabel->setText(sparkleUpdater->statusString());
@@ -405,7 +416,7 @@ void GeneralSettings::setAndCheckNewUpdateChannel(const QString &newChannel) {
         updater->setUpdateUrl(Updater::updateUrl());
         updater->checkForUpdate();
     }
-#if defined(Q_OS_MAC) && defined(HAVE_SPARKLE)
+#if defined(Q_OS_MACOS) && defined(HAVE_SPARKLE)
     else if (auto updater = qobject_cast<SparkleUpdater *>(Updater::instance())) {
         updater->setUpdateUrl(Updater::updateUrl());
         updater->checkForUpdate();
@@ -500,7 +511,7 @@ void GeneralSettings::slotUpdateChannelChanged()
 
 void GeneralSettings::slotUpdateCheckNow()
 {
-#if defined(Q_OS_MAC) && defined(HAVE_SPARKLE)
+#if defined(Q_OS_MACOS) && defined(HAVE_SPARKLE)
     auto *updater = qobject_cast<SparkleUpdater *>(Updater::instance());
 #else
     auto *updater = qobject_cast<OCUpdater *>(Updater::instance());
@@ -594,6 +605,12 @@ void GeneralSettings::slotToggleCallNotifications(bool enable)
     cfgFile.setShowCallNotifications(enable);
 }
 
+void GeneralSettings::slotToggleQuotaWarningNotifications(bool enable)
+{
+    ConfigFile cfgFile;
+    cfgFile.setShowQuotaWarningNotifications(enable);
+}
+
 void GeneralSettings::slotShowInExplorerNavigationPane(bool checked)
 {
     ConfigFile cfgFile;
@@ -669,7 +686,7 @@ void GeneralSettings::customizeStyle()
 #endif
 }
 
-void GeneralSettings::slotRemotePollIntervalChanged(int seconds) 
+void GeneralSettings::slotRemotePollIntervalChanged(int seconds)
 {
     if (_currentlyLoading) {
         return;
@@ -680,7 +697,7 @@ void GeneralSettings::slotRemotePollIntervalChanged(int seconds)
     cfgFile.setRemotePollInterval(interval);
 }
 
-void GeneralSettings::updatePollIntervalVisibility() 
+void GeneralSettings::updatePollIntervalVisibility()
 {
     const auto accounts = AccountManager::instance()->accounts();
     const auto pushAvailable = std::any_of(accounts.cbegin(), accounts.cend(), [](const AccountStatePtr &accountState) -> bool {
